# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/group/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/litecms/group/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Litecms\\Group\\": "packages/litecms/group/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\Group\Providers\GroupServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Group'  => Litecms\Group\Facades\Group::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\GroupTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\Group\Providers\GroupServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\Group\Providers\GroupServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\Group\Providers\GroupServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/group/{modulename}

**User**

    http://path-to-route-folder/user/group/{modulename}

**Public**

    http://path-to-route-folder/groups


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/group/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/group/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/group/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/group/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/group/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/group/{modulename}/{slug}
    METHOD: GET